@@ -1,5 +1,5 @@
 from bolinette.core import functions
 from bolinette.core.model import Model, ModelMetadata, ModelProperty
 from bolinette.core.mixin import Mixin
-from bolinette.core.repositories import Repository, RelationalRepository, CollectionRepository
+from bolinette.core.repository import Repository
 from bolinette.core.service import Service, ServiceMetadata, SimpleService, HistorizedService
