@@ -1,9 +1,9 @@
-from bolinette import types, blnt
+from bolinette import types, core, mapping
 from bolinette.decorators import model
 
 
 @model('file')
-class File(blnt.Model):
+class File(core.Model):
     id = types.defs.Column(types.db.Integer, primary_key=True)
     key = types.defs.Column(types.db.String, nullable=False)
     name = types.defs.Column(types.db.String, nullable=False)
@@ -12,10 +12,10 @@ class File(blnt.Model):
     @classmethod
     def responses(cls):
         yield [
-            types.mapping.Column(cls.key),
-            types.mapping.Column(cls.name),
-            types.mapping.Column(cls.mime)
+            mapping.Column(cls.key),
+            mapping.Column(cls.name),
+            mapping.Column(cls.mime)
         ]
         yield 'minimal', [
-            types.mapping.Column(cls.key)
+            mapping.Column(cls.key)
         ]
